import React from 'react';
import ReactDOM from 'react-dom';
import * as type from '../_utils/type';
import Notification from './Notification';

var _render = function render(props) {
  var isOpen = false;
  var messageQueue = [];

  var handleClose = function handleClose() {
    isOpen = false;
    var head = messageQueue[0] && messageQueue.shift();
    head && _render(head);
  };

  _render = function render(nextProps) {
    props = Object.assign({}, props, nextProps, {
      onClose: handleClose
    });

    if (isOpen) {
      return messageQueue.push(props);
    }

    isOpen = true;
    var container = document.createElement('div');
    ReactDOM.render(React.createElement(Notification, props), container);
  };

  _render();
};

var getNotificationParams = function getNotificationParams(args) {
  var stringArray = [];
  var options = {
    focused: 'accept'
  };
  var duration = 1500;
  Array.from(args).forEach(function (v) {
    type.isNumber(v) && (duration = v);
    type.isString(v) && stringArray.push(v);
    type.isObject(v) && Object.assign(options, v);
  });
  return {
    message: stringArray[0] || 'Notification message must be provided.',
    acceptLabel: stringArray[1] || 'OK',
    duration: duration,
    options: options
  };
};

var notification = {
  success: function success() {
    var _getNotificationParam = getNotificationParams(arguments),
        message = _getNotificationParam.message,
        duration = _getNotificationParam.duration,
        options = _getNotificationParam.options;

    _render({
      message: message,
      acceptLabel: null,
      options: options,
      type: 'success',
      backdrop: false,
      lock: false,
      autoClose: true,
      duration: duration,
      open: true
    });
  },
  info: function info() {
    var _getNotificationParam2 = getNotificationParams(arguments),
        message = _getNotificationParam2.message,
        acceptLabel = _getNotificationParam2.acceptLabel,
        options = _getNotificationParam2.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      options: options,
      type: 'info',
      backdrop: true,
      lock: true,
      autoClose: false,
      open: true
    });
  },
  warning: function warning() {
    var _getNotificationParam3 = getNotificationParams(arguments),
        message = _getNotificationParam3.message,
        acceptLabel = _getNotificationParam3.acceptLabel,
        options = _getNotificationParam3.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      options: options,
      type: 'warning',
      backdrop: true,
      lock: true,
      autoClose: false,
      open: true
    });
  },
  error: function error() {
    var _getNotificationParam4 = getNotificationParams(arguments),
        message = _getNotificationParam4.message,
        acceptLabel = _getNotificationParam4.acceptLabel,
        options = _getNotificationParam4.options;

    _render({
      message: message,
      acceptLabel: acceptLabel,
      options: options,
      type: 'error',
      backdrop: true,
      lock: true,
      autoClose: false,
      open: true
    });
  },
  close: function close() {
    _render({
      open: false
    });
  }
};
export default notification;